@@ -41,11 +41,11 @@ def initialize_project() -> "Project":
     return Project(auth=_auth, project_id=_auth.project_id)
 
 
-def initialize_catalog(backend: str = "ONE_ATLAS") -> "Catalog":
+def initialize_catalog() -> "Catalog":
     """Directly returns a Catalog object."""
     if _auth is None:
         raise RuntimeError("Not authenticated, call up42.authenticate() first")
-    return Catalog(auth=_auth, backend=backend)
+    return Catalog(auth=_auth)
 
 
 def initialize_workflow(workflow_id) -> "Workflow":
@@ -132,3 +132,18 @@ def plot_results(
 ) -> None:
     tools = Tools(auth=_auth)
     tools.plot_results(figsize, filepaths, titles)
+
+
+def settings(log=True):
+    if log:
+        logger.info(
+            "Logging enabled (default) - use up42.settings(log=False) to disable."
+        )
+    else:
+        logger.info("Logging disabled - use up42.settings(log=True) to reactivate.")
+
+    # pylint: disable=expression-not-assigned
+    [
+        setattr(logging.getLogger(name), "disabled", not log)
+        for name in logging.root.manager.loggerDict
+    ]
