@@ -18,25 +18,40 @@ logger = get_logger(__name__)
 # TODO: Midterm add catalog results class? Scenes() etc. that also as feedback to workflow input.
 # Scenes() would be dataframe with quicklook preview images in it.
 
-supported_sensors_blocks = {
-    "pleiades": ["oneatlas-pleiades-fullscene", "oneatlas-pleiades-aoiclipped",],
-    "spot": ["oneatlas-spot-fullscene", "oneatlas-spot-aoiclipped",],
-    "sentinel1": [
-        "sobloo-sentinel1-l1c-grd-full",
-        "sobloo-sentinel1-l1c-grd-aoiclipped",
-        "sobloo-sentinel1-l1c-slc-full",
-    ],
-    "sentinel2": [
-        "sobloo-sentinel2-lic-msi-full",
-        "sobloo-sentinel2-lic-msi-aoiclipped",
-    ],
-    "sentinel3": ["sobloo-sentinel3-full"],
-    "sentinel5p": ["sobloo-sentinel5-preview-full",],
+supported_sensors = {
+    "pleiades": {
+        "blocks": ["oneatlas-pleiades-fullscene", "oneatlas-pleiades-aoiclipped",],
+        "provider": "oneatlas",
+    },
+    "spot": {
+        "blocks": ["oneatlas-spot-fullscene", "oneatlas-spot-aoiclipped",],
+        "provider": "oneatlas",
+    },
+    "sentinel1": {
+        "blocks": [
+            "sobloo-sentinel1-l1c-grd-full",
+            "sobloo-sentinel1-l1c-grd-aoiclipped",
+            "sobloo-sentinel1-l1c-slc-full",
+        ],
+        "provider": "sobloo-image",
+    },
+    "sentinel2": {
+        "blocks": [
+            "sobloo-sentinel2-lic-msi-full",
+            "sobloo-sentinel2-lic-msi-aoiclipped",
+        ],
+        "provider": "sobloo-image",
+    },
+    "sentinel3": {"blocks": ["sobloo-sentinel3-full"], "provider": "sobloo-image"},
+    "sentinel5p": {
+        "blocks": ["sobloo-sentinel5-preview-full",],
+        "provider": "sobloo-image",
+    },
 }
 
 # pylint: disable=duplicate-code
 class Catalog(Tools):
-    def __init__(self, auth: Auth, backend: str = "ONE_ATLAS"):
+    def __init__(self, auth: Auth):
         """The Catalog class enables access to the UP42 catalog search. You can search
         for satellite image scenes for different sensors and criteria like cloud cover etc.
 
@@ -44,11 +59,10 @@ class Catalog(Tools):
             construct_parameters, search, download_quicklooks
         """
         self.auth = auth
-        self.querystring = {"backend": backend}
         self.quicklooks = None
 
     def __repr__(self):
-        return f"Catalog(querystring={self.querystring}, auth={self.auth})"
+        return f"Catalog(auth={self.auth})"
 
     # pylint: disable=dangerous-default-value
     @staticmethod
@@ -80,7 +94,7 @@ class Catalog(Tools):
             start_date: Query period starting day, format "2020-01-01".
             end_date: Query period ending day, format "2020-01-01".
             sensors: The satellite sensor(s) to search for, one or multiple of
-                ["pleiades", "spot", "sentinel1", "sentinel2", "sentinel3", "sentinel5"]
+                ["pleiades", "spot", "sentinel1", "sentinel2", "sentinel3", "sentinel5p"]
             limit: The maximum number of search results to return.
             max_cloudcover: Maximum cloudcover % - 100 will return all scenes, 8.4 will return all
                 scenes with 8.4 or less cloudcover.
@@ -94,12 +108,12 @@ class Catalog(Tools):
         datetime = f"{start_date}T00:00:00Z/{end_date}T00:00:00Z"
         block_filters: List[str] = []
         for sensor in sensors:
-            if sensor not in list(supported_sensors_blocks.keys()):
+            if sensor not in list(supported_sensors.keys()):
                 raise ValueError(
                     f"Currently only these sensors are supported: "
-                    f"{list(supported_sensors_blocks.keys())}"
+                    f"{list(supported_sensors.keys())}"
                 )
-            block_filters.extend(supported_sensors_blocks[sensor])
+            block_filters.extend(supported_sensors[sensor]["blocks"])
         query_filters = {
             "cloudCoverage": {"lte": max_cloudcover},
             "dataBlock": {"in": block_filters},
@@ -158,11 +172,8 @@ class Catalog(Tools):
         """
         logger.info("Searching catalog with: %r", search_paramaters)
         url = f"{self.auth._endpoint()}/catalog/stac/search"
-        response_json = self.auth._request(
-            "POST", url, search_paramaters, self.querystring
-        )
+        response_json = self.auth._request("POST", url, search_paramaters)
         logger.info("%d results returned.", len(response_json["features"]))
-        # UP42 results are always in EPSG 4326
         dst_crs = "EPSG:4326"
         df = GeoDataFrame.from_features(response_json, crs=dst_crs)
         if df.empty:
@@ -171,16 +182,17 @@ class Catalog(Tools):
             else:
                 return df.__geo_interface__
 
-        # TODO: Resolve on backend
         # Filter to actual geometries intersecting the aoi (Sobloo search uses a rectangular
         # bounds geometry, can contain scenes that touch the aoi bbox, but not the aoi.
         # So number returned images not consistent with set limit.
+        # TODO: Resolve on backend
         geometry = search_paramaters["intersects"]
         poly = shape(geometry)
         df = df[df.intersects(poly)]
         df = df.reset_index()
 
         # Make scene_id more easily accessible
+        # TODO: Add by default to results, independent of sensor.
         def _get_scene_id(row):
             if row["providerName"] == "oneatlas":
                 row["scene_id"] = row["providerProperties"]["parentIdentifier"]
@@ -190,9 +202,9 @@ class Catalog(Tools):
                 ]
             return row
 
-        # pylint: disable=unnecessary-lambda
-        df = df.apply(lambda row: _get_scene_id(row), axis=1)
-        df.crs = dst_crs  # apply resets crs
+        df = df.apply(_get_scene_id, axis=1)
+        df.crs = dst_crs  # apply resets the crs
+
         if as_dataframe:
             return df
         else:
@@ -201,34 +213,33 @@ class Catalog(Tools):
     def download_quicklooks(
         self,
         image_ids: List[str],
-        provider: str = "oneatlas",
+        sensor: str,
         output_directory: Union[str, Path, None] = None,
     ) -> List[str]:
         """
-        Gets the quicklooks of scenes, from oneatlas.
+        Gets the quicklooks of scenes from a single sensor. After download, can
+        be plotted via catalog.plot_quicklooks().
 
-        After download, can be plotted via catalog.plot_quicklooks().
         Args:
             image_ids: provider image_id in the form "6dffb8be-c2ab-46e3-9c1c-6958a54e4527"
-            provider:  One of "oneatlas" (pleiades, spot) or sobloo (Sentinel1-Sentinel5p).
+            sensors: The satellite sensor(s) to search for, one of
+                "pleiades", "spot", "sentinel1", "sentinel2", "sentinel3", "sentinel5p".
             output_directory: The file output directory, defaults to the current working
                 directory.
 
         Returns:
             List of quicklook image output file paths.
         """
+        if sensor not in list(supported_sensors.keys()):
+            raise ValueError(
+                f"Currently only these sensors are supported: "
+                f"{list(supported_sensors.keys())}"
+            )
+        provider = supported_sensors[sensor]["provider"]
         logger.info(
             "Getting quicklooks from provider %s for image_ids: %s", provider, image_ids
         )
 
-        if provider == "sobloo":
-            provider = "sobloo-image"
-        implemented_providers = ["sobloo-image", "oneatlas"]
-        if provider not in implemented_providers:
-            raise ValueError(
-                "This provider is not yet implemented for quicklook download!"
-            )
-
         if output_directory is None:
             output_directory = (
                 Path.cwd() / f"project_{self.auth.project_id}" / "catalog"
