@@ -1,19 +1,23 @@
 import copy
 import logging
-from typing import Dict, List, Union
+from typing import Dict, List, Union, Tuple
 from pathlib import Path
 import tempfile
 import tarfile
+import math
 
 import folium
 from folium.plugins import Draw
 from geopandas import GeoDataFrame
 import shapely
+import rasterio
+from rasterio.plot import show
 from shapely.geometry import Point, Polygon
 from geojson import Feature, FeatureCollection
 from geojson import Polygon as geojson_Polygon
 import requests
 from tqdm import tqdm
+import matplotlib.pyplot as plt
 
 LOG_FORMAT = "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
 
@@ -70,19 +74,21 @@ def download_results_from_gcs(
     out_filepaths: List[str] = []
     with tarfile.open(tgz_file) as tar:
         members = tar.getmembers()
-        files = [
-            i for i in members if i.isfile() and str(Path(i.name).name) != "data.json"
-        ]
+        files = [f for f in members if f.isfile()]
         for file in files:
             f = tar.extractfile(file)
             content = f.read()  # type: ignore
-            out_fp = output_directory / f"result_{Path(file.name).name}"
+            out_fp = output_directory / f"{Path(file.name).name}"
             with open(out_fp, "wb") as dst:
                 dst.write(content)
             out_filepaths.append(str(out_fp))
 
-    logger.info("Download successful of %s files %s", len(out_filepaths), out_filepaths)
-
+    logger.info(
+        "Download successful of %s files to output_directory '%s': %s",
+        len(out_filepaths),
+        output_directory,
+        [Path(p).name for p in out_filepaths],
+    )
     return out_filepaths
 
 
@@ -196,6 +202,64 @@ class DrawFoliumOverride(Draw):
             figure.html.add_child(Element(export_button), name="export_button")
 
 
+def _plot_images(
+    plot_file_format: List[str],
+    figsize: Tuple[int, int] = (8, 8),
+    filepaths: List[Union[str, Path]] = None,
+    titles: List[str] = None,
+) -> None:
+    """
+    Plots image data (quicklooks or results)
+
+    Args:
+        plot_file_format: List of accepted image file formats e.g. [".tif"]
+        figsize: matplotlib figure size.
+        filepaths: Paths to images to plot. Optional, by default picks up the last
+            downloaded results.
+        titles: Optional list of titles for the subplots.
+
+    """
+    if not isinstance(filepaths, list):
+        filepaths = [filepaths]  # type: ignore
+    filepaths = [Path(path) for path in filepaths]
+
+    imagepaths = [
+        path for path in filepaths if str(path.suffix) in plot_file_format  # type: ignore
+    ]
+    if not imagepaths:
+        raise ValueError(
+            f"Only files of the formats {plot_file_format} can " "currently be plotted."
+        )
+
+    if not titles:
+        titles = [Path(fp).stem for fp in imagepaths]
+    if not isinstance(titles, list):
+        titles = [titles]  # type: ignore
+
+    if len(imagepaths) < 2:
+        nrows, ncols = 1, 1
+    else:
+        ncols = 3
+        nrows = int(math.ceil(len(imagepaths) / float(ncols)))
+
+    _, axs = plt.subplots(nrows=nrows, ncols=ncols, figsize=figsize)
+    if len(imagepaths) > 1:
+        axs = axs.ravel()
+    else:
+        axs = [axs]
+    for idx, (fp, title) in enumerate(zip(imagepaths, titles)):
+        with rasterio.open(fp) as src:
+            img_array = src.read()[:3, :, :]
+            # TODO: Handle more band configurations.
+            # TODO: add histogram equalization?
+            show(
+                img_array, transform=src.transform, title=title, ax=axs[idx],
+            )
+        axs[idx].set_axis_off()
+    plt.tight_layout()
+    plt.show()
+
+
 def any_vector_to_fc(
     vector: Union[
         Dict, Feature, FeatureCollection, List, GeoDataFrame, Polygon, Point,
